gboolean update_dir(GtkTreeView * treeview, GtkTreeRowReference * reference);

void remove_it(GtkTreeView * treeview, GtkTreeRowReference * reference);
gint local_monitor(GtkTreeView * treeview,gboolean force);
